@@ -6,3 +6,6 @@ from evalml.pipelines.components.transformers.encoders.target_encoder import (
     TargetEncoder,
 )
 from evalml.pipelines.components.transformers.encoders.label_encoder import LabelEncoder
+from evalml.pipelines.components.transformers.encoders.ordinal_encoder import (
+    OrdinalEncoder,
+)
