@@ -3,10 +3,8 @@ from __future__ import annotations
 
 import logging
 
-import matplotlib.pyplot as plt
-import numpy as np
 import pandas as pd
-import sklearn.exceptions
+from pandas.core.index import Int64Index
 from skopt.space import Integer
 from sktime.forecasting.base._fh import ForecastingHorizon
 from statsmodels.tsa.seasonal import seasonal_decompose
@@ -57,27 +55,9 @@ class PolynomialDecomposer(Decomposer):
         random_seed: int = 0,
         **kwargs,
     ):
-        def raise_typeerror_if_not_int(var_name, var_value):
-            if not isinstance(var_value, int):
-                if isinstance(var_value, float) and var_value.is_integer():
-                    var_value = int(var_value)
-                else:
-                    raise TypeError(
-                        f"Parameter 'degree' must be an integer!: Received {type(degree).__name__}",
-                    )
-            return var_value
-
         self.logger = logging.getLogger(__name__)
-        degree = raise_typeerror_if_not_int("degree", degree)
-        self.seasonal_period = raise_typeerror_if_not_int(
-            "seasonal_period",
-            seasonal_period,
-        )
 
-        params = {"degree": degree, "seasonal_period": self.seasonal_period}
-        params.update(kwargs)
         error_msg = "sktime is not installed. Please install using 'pip install sktime'"
-
         trend = import_or_raise("sktime.forecasting.trend", error_msg=error_msg)
         detrend = import_or_raise(
             "sktime.transformations.series.detrend",
@@ -86,54 +66,15 @@ class PolynomialDecomposer(Decomposer):
 
         decomposer = detrend.Detrender(trend.PolynomialTrendForecaster(degree=degree))
 
-        self.time_index = time_index
-        params["time_index"] = time_index
-
         super().__init__(
-            parameters=params,
             component_obj=decomposer,
             random_seed=random_seed,
+            degree=degree,
+            seasonal_period=seasonal_period,
+            time_index=time_index,
+            **kwargs,
         )
 
-    def _build_seasonal_signal(self, y, periodic_signal, periodicity, frequency):
-        """Projects the cyclical, seasonal signal forward to cover the target data.
-
-        Args:
-            y (pandas.Series): Target data to be transformed
-            periodic_signal (pandas.Series): Single period of the detected seasonal signal
-            periodicity (int): Number of time units in a single cycle of the seasonal signal
-            frequency (str): String representing the detected frequency of the time series data.
-                Uses the same codes as the freqstr attribute of a pandas Series with DatetimeIndex.
-                e.g. "D", "M", "Y" for day, month and year respectively
-                See: https://pandas.pydata.org/docs/user_guide/timeseries.html#timeseries-offset-aliases
-                See: https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.to_timedelta.html
-
-        Returns:
-            pandas.Series: the seasonal signal extended to cover the target data to be transformed
-        """
-        # Determine where the seasonality starts
-        first_index_diff = y.index[0] - periodic_signal.index[0]
-        delta = pd.to_timedelta(1, frequency)
-        period = pd.to_timedelta(periodicity, frequency)
-
-        # Determine which index of the sample of seasonal data the transformed data starts at
-        transform_first_ind = int((first_index_diff % period) / delta)
-
-        # Cycle the sample of seasonal data so the transformed data's effective index is first
-        rotated_seasonal_sample = np.roll(
-            periodic_signal.T.values,
-            -transform_first_ind,
-        )
-
-        # Repeat the single, rotated period of seasonal data to cover the entirety of the data
-        # to be transformed.
-        seasonal = np.tile(rotated_seasonal_sample, len(y) // periodicity + 1).T[
-            : len(y)
-        ]  # The extrapolated seasonal data will be too long, so truncate.
-
-        # Add the date times back in.
-        return pd.Series(seasonal, index=y.index)
-
     def fit(self, X: pd.DataFrame, y: pd.Series = None) -> PolynomialDecomposer:
         """Fits the PolynomialDecomposer and determine the seasonal signal.
 
@@ -149,18 +90,22 @@ class PolynomialDecomposer(Decomposer):
             self
 
         Raises:
+            NotImplementedError: If the input data has a frequency of "month-begin".  This isn't supported by statsmodels decompose
+                as the freqstr "MS" is misinterpreted as milliseconds.
             ValueError: If y is None.
             ValueError: If target data doesn't have DatetimeIndex AND no Datetime features in features data
         """
-        if y is None:
-            raise ValueError("y cannot be None for PolynomialDecomposer!")
+        self.original_index = y.index if y is not None else None
+        X, y = self._check_target(X, y)
+        self._map_dt_to_integer(self.original_index, y.index)
 
-        # Change the y index to a matching datetimeindex or else we get a failure
-        # in ForecastingHorizon during decomposition.
-        if not isinstance(y.index, pd.DatetimeIndex):
-            y = self._set_time_index(X, y)
+        if y.index.freqstr == "MS":
+            raise NotImplementedError(
+                "statsmodels decompose does not handle datasets with month-begin (e.g. 10/01/2000, 11/01/2000)"
+                "datetime data.  These values are incorrectly interpreted as milliseconds.",
+            )
 
-        # Copying y as we might modify it's index
+        # Copying y as we might modify its index
         y_orig = infer_feature_types(y).copy()
         self._component_obj.fit(y_orig)
 
@@ -173,16 +118,14 @@ class PolynomialDecomposer(Decomposer):
         # the given array.  We'll extract the first iteration and save it for use in .transform()
         # TODO: Resolve with https://github.com/alteryx/evalml/issues/3708
         if self.seasonal_period == -1:
-            self.periodicity = freq_to_period(self.frequency)
-            self.seasonal_period = self.periodicity
-        else:
-            self.periodicity = self.seasonal_period
+            self.seasonal_period = freq_to_period(self.frequency)
 
-        self.seasonality = seasonal_decompose(
+        self.seasonal = seasonal_decompose(
             y_detrended_with_time_index,
-            period=self.periodicity,
-        ).seasonal[0 : self.periodicity]
-
+            period=self.seasonal_period,
+        ).seasonal
+        self.seasonality = self.seasonal[0 : self.seasonal_period]
+        self.trend = y - (y_detrended_with_time_index - self.seasonal) - self.seasonal
         return self
 
     def transform(
@@ -193,7 +136,7 @@ class PolynomialDecomposer(Decomposer):
         """Transforms the target data by removing the polynomial trend and rolling average seasonality.
 
         Applies the fit polynomial detrender to the target data, removing the additive polynomial trend. Then,
-        utilizes the first period's worth of seasonal data determined in the .train() function to extrapolate
+        utilizes the first period's worth of seasonal data determined in the .fit() function to extrapolate
         the seasonal signal of the data to be transformed.  This seasonal signal is also assumed to be additive
         and is removed.
 
@@ -210,52 +153,38 @@ class PolynomialDecomposer(Decomposer):
         """
         if y is None:
             return X, y
+        original_index = y.index
+        X, y = self._check_target(X, y)
+
+        self._check_oos_past(y)
 
         # Give the internal target signal a datetime index built from X
         y = y.copy()
-        if not isinstance(y.index, pd.DatetimeIndex):
-            y = self._set_time_index(X, y)
 
         # Remove polynomial trend then seasonality of detrended signal
         y_ww = infer_feature_types(y)
         y_detrended = self._component_obj.transform(y_ww)
 
-        if isinstance(y.index, pd.DatetimeIndex):
-            # Repeat the seasonal signal over the target data
-            seasonal = np.tile(
-                self.seasonality.T,
-                len(y_detrended) // self.periodicity + 1,
-            ).T[: len(y_detrended)]
+        seasonal = self._project_seasonal(
+            y,
+            self.seasonality,
+            self.seasonal_period,
+            self.frequency,
+        )
 
         y_t = pd.Series(y_detrended - seasonal)
         y_t.ww.init(logical_type="double")
+        y_t.index = original_index
         return X, y_t
 
-    def fit_transform(
-        self,
-        X: pd.DataFrame,
-        y: pd.Series = None,
-    ) -> tuple[pd.DataFrame, pd.Series]:
-        """Removes fitted trend and seasonality from target variable.
-
-        Args:
-            X (pd.DataFrame, optional): Ignored.
-            y (pd.Series): Target variable to detrend and deseasonalize.
-
-        Returns:
-            tuple of pd.DataFrame, pd.Series: The first element are the input features returned without modification.
-                The second element is the target variable y with the fitted trend removed.
-        """
-        return self.fit(X, y).transform(X, y)
-
-    def inverse_transform(self, y: pd.Series) -> tuple[pd.DataFrame, pd.Series]:
+    def inverse_transform(self, y_t: pd.Series) -> tuple[pd.DataFrame, pd.Series]:
         """Adds back fitted trend and seasonality to target variable.
 
         The polynomial trend is added back into the signal, calling the detrender's inverse_transform().
         Then, the seasonality is projected forward to and added back into the signal.
 
         Args:
-            y (pd.Series): Target variable.
+            y_t (pd.Series): Target variable.
 
         Returns:
             tuple of pd.DataFrame, pd.Series: The first element are the input features returned without modification.
@@ -264,24 +193,84 @@ class PolynomialDecomposer(Decomposer):
         Raises:
             ValueError: If y is None.
         """
-        if y is None:
-            raise ValueError("y cannot be None for PolynomialDecomposer!")
-        y_ww = infer_feature_types(y)
+        if y_t is None:
+            raise ValueError("y_t cannot be None for Decomposer!")
+        original_index = y_t.index
 
-        # Add polynomial trend back to signal
-        y_retrended = self._component_obj.inverse_transform(y_ww)
+        y_t = infer_feature_types(y_t).copy()
+        self._check_oos_past(y_t)
 
-        seasonal = self._build_seasonal_signal(
-            y_ww,
-            self.seasonality,
-            self.periodicity,
-            self.frequency,
-        )
-        y_t = infer_feature_types(pd.Series(y_retrended + seasonal, index=y_ww.index))
-        return y_t
+        index = self._choose_proper_index(y_t)
+
+        y_in_sample = pd.Series([])
+        y_out_of_sample = pd.Series([])
+
+        # For partially and wholly in-sample data, retrieve stored results.
+        if index[0] <= y_t.index[0] <= index[-1]:
+            left_index = y_t.index[0]
+            right_index = min(y_t.index[-1], index[-1])
+
+            if isinstance(y_t.index, (pd.RangeIndex, Int64Index)):
+                y_t_ind = pd.RangeIndex(
+                    start=left_index,
+                    stop=right_index + 1,
+                )  # stop value is not inclusive
+            elif isinstance(y_t.index, pd.DatetimeIndex):
+                y_t_ind = pd.DatetimeIndex(
+                    pd.date_range(left_index, end=right_index),
+                )  # end value is inclusive
+
+            # Build index
+            y_t_in_sample = y_t[y_t_ind]
+
+            # Convert y_t to datetime index to use the built in component
+            if isinstance(y_t.index, (pd.RangeIndex, Int64Index)):
+                y_t_dt_ind = self._convert_int_index_to_dt_index(y_t_in_sample.index)
+            elif isinstance(y_t.index, pd.DatetimeIndex):
+                y_t_dt_ind = y_t_ind
+            trend = self._component_obj.inverse_transform(
+                y_t_in_sample.set_axis(y_t_dt_ind),
+            )
+
+            # self.seasonal will always have a datetime index
+            seasonal = self.seasonal[y_t_dt_ind].set_axis(y_t_dt_ind)
+            y_in_sample = trend + seasonal
+            y_in_sample = y_in_sample.dropna()
+
+        # For out of sample data....
+        if y_t.index[-1] > index[-1]:
+            try:
+                # ...that is partially out of sample and partially in sample.
+                truncated_y_t = y_t[y_t.index.get_loc(index[-1]) + 1 :]
+            except KeyError:
+                # ...that is entirely out of sample.
+                truncated_y_t = y_t
+
+            projected_seasonality = self._project_seasonal(
+                truncated_y_t,
+                self.seasonality,
+                self.seasonal_period,
+                self.frequency,
+            )
+
+            if isinstance(truncated_y_t.index, (pd.RangeIndex, Int64Index)):
+                dt_index = self._convert_int_index_to_dt_index(truncated_y_t.index)
+                truncated_y_t.index = dt_index
+                projected_seasonality.index = dt_index
+            retrended_y = self._component_obj.inverse_transform(truncated_y_t)
+
+            y_out_of_sample = infer_feature_types(
+                pd.Series(
+                    retrended_y + projected_seasonality,
+                    index=truncated_y_t.index,
+                ),
+            )
+        y = y_in_sample.append(y_out_of_sample)
+        y.index = original_index
+        return y
 
     def get_trend_dataframe(self, X: pd.DataFrame, y: pd.Series) -> list[pd.DataFrame]:
-        """Return a list of dataframes with 3 columns: trend, seasonality, residual.
+        """Return a list of dataframes with 4 columns: signal, trend, seasonality, residual.
 
         Scikit-learn's PolynomialForecaster is used to generate the trend portion of the target data. statsmodel's
         seasonal_decompose is used to generate the seasonality of the data.
@@ -324,12 +313,9 @@ class PolynomialDecomposer(Decomposer):
             forecaster = (
                 self._component_obj.forecaster_
             )  # the .forecaster attribute is an unfitted version
-            try:
-                trend = forecaster.predict(fh=fh, X=y)
-            except (sklearn.exceptions.NotFittedError, AttributeError):
-                raise ValueError(
-                    "PolynomialDecomposer has not been fit yet.  Please fit it and then build the decomposed dataframe.",
-                )
+
+            trend = forecaster.predict(fh=fh, X=y)
+
             seasonality = seasonal_decompose(
                 y - trend,
                 period=self.seasonal_period,
@@ -351,32 +337,3 @@ class PolynomialDecomposer(Decomposer):
                 result_dfs.append(_decompose_target(X, y[colname], fh))
 
         return result_dfs
-
-    def plot_decomposition(self, X: pd.DataFrame, y: pd.Series, show=False):
-        """Plots the decomposition of the target signal.
-
-        Args:
-            X (pd.DataFrame): Input data with time series data in index.
-            y (pd.Series or pd.DataFrame): Target variable data provided as a Series for univariate problems or
-                a DataFrame for multivariate problems.
-            show (bool): Whether to display the plot or not. Defaults to False.
-
-        Returns:
-            matplotlib.pyplot.Figure, matplotlib.pyplot.Axes: The figure and axes that have the decompositions
-                plotted on them
-
-        """
-        decomposition_results = self.get_trend_dataframe(X, y)
-        fig, axs = plt.subplots(4)
-        fig.set_size_inches(18.5, 14.5)
-        axs[0].plot(decomposition_results[0]["signal"], "r")
-        axs[0].set_title("signal")
-        axs[1].plot(decomposition_results[0]["trend"], "b")
-        axs[1].set_title("trend")
-        axs[2].plot(decomposition_results[0]["seasonality"], "g")
-        axs[2].set_title("seasonality")
-        axs[3].plot(decomposition_results[0]["residual"], "y")
-        axs[3].set_title("residual")
-        if show:  # pragma: no cover
-            plt.show()
-        return fig, axs
