@@ -40,7 +40,6 @@ from evalml.pipelines.components.utils import (
     handle_component_class,
 )
 from evalml.pipelines.utils import (
-    _UNSUPPORTED_FREQUENCIES_STL_DECOMPOSER,
     _get_pipeline_base_class,
     _get_preprocessing_components,
     _make_pipeline_from_multiple_graphs,
@@ -197,10 +196,23 @@ def test_make_pipeline(
         ProblemTypes.TIME_SERIES_REGRESSION,
     ],
 )
-@pytest.mark.parametrize("frequency", ["D", "MS", "A", "T"])
-def test_make_pipeline_controls_decomposer(
+@pytest.mark.parametrize(
+    "frequency, should_decomp",
+    [
+        ("D", True),
+        ("MS", True),
+        ("A", False),
+        ("T", False),
+        ("10T", False),
+        ("AS-JAN", False),
+        ("YS", False),
+        (None, False),
+    ],
+)
+def test_make_pipeline_controls_decomposer_time_series(
     problem_type,
     frequency,
+    should_decomp,
     get_test_data_from_configuration,
 ):
     X, y = get_test_data_from_configuration(
@@ -208,7 +220,16 @@ def test_make_pipeline_controls_decomposer(
         problem_type,
         column_names=["dates", "numerical"],
     )
-    X.ww["dates"] = pd.Series(pd.date_range("2000-02-03", periods=20, freq=frequency))
+    if frequency is None:
+        X.ww["dates"] = pd.Series(
+            pd.date_range("2000-02-03", periods=10, freq=frequency).append(
+                pd.date_range("2000-02-15", periods=10, freq=frequency),
+            ),
+        )
+    else:
+        X.ww["dates"] = pd.Series(
+            pd.date_range("2000-02-03", periods=20, freq=frequency),
+        )
     parameters = {
         "pipeline": {
             "time_index": "date",
@@ -221,14 +242,10 @@ def test_make_pipeline_controls_decomposer(
     pipeline_class = _get_pipeline_base_class(problem_type)
     for estimator_class in estimators:
         if problem_type in estimator_class.supported_problem_types:
-
             pipeline = make_pipeline(X, y, estimator_class, problem_type, parameters)
             assert isinstance(pipeline, pipeline_class)
 
-            if (
-                is_regression(problem_type)
-                and frequency not in _UNSUPPORTED_FREQUENCIES_STL_DECOMPOSER
-            ):
+            if is_regression(problem_type) and should_decomp:
                 assert "STL Decomposer" in pipeline.component_graph.compute_order
             else:
                 assert "STL Decomposer" not in pipeline.component_graph.compute_order
